cocos.audio.pygame.version module — cocos v0.6.5 documentation

# cocos.audio.pygame.version module

Simply the current installed pygame version. The version information is stored in the regular pygame module as ‘pygame.ver’. Keeping the version information also available in a separate module allows you to test the pygame version without importing the main pygame module.

The python version information should always compare greater than any previous releases. (hmm, until we get to versions > 10)